@@ -217,10 +217,10 @@ def test_dara1_instant():
         'market_last_transaction': jdatetime(1399, 11, 8, 15, 21, 59),
         'nav': 190671,
         'nav_datetime': jdatetime(1399, 11, 8, 15, 40),
-        'otc_status': 'F',
-        'otc_tno': 494135,
-        'otc_tval': 122240030535934.0,
-        'otc_tvol': 2168547032.0,
+        'fb_status': 'F',
+        'fb_tno': 494135,
+        'fb_tval': 122240030535934.0,
+        'fb_tvol': 2168547032.0,
         'pc': 151580,
         'pd1': 150120,
         'pd2': 150000,
@@ -497,10 +497,10 @@ def test_parse_index():
         'derivatives_tval': 0.0,
         'derivatives_tvol': 0.0,
         'market_last_transaction': jdatetime(1300, 1, 14, 6, 40, 12),
-        'otc_status': 'C',
-        'otc_tno': 0,
-        'otc_tval': 0.0,
-        'otc_tvol': 0.0,
+        'fb_status': 'C',
+        'fb_tno': 0,
+        'fb_tval': 0.0,
+        'fb_tvol': 0.0,
         'tse_index': 1294521.64,
         'tse_index_change': -8671.45,
         'tse_status': 'F',
@@ -514,10 +514,10 @@ def test_parse_index():
         'derivatives_tval': 31470939000.0,
         'derivatives_tvol': 101096.0,
         'market_last_transaction': jdatetime(1399, 12, 16, 15, 45, 46),
-        'otc_status': 'N',
-        'otc_tno': 342228,
-        'otc_tval': 163701347122693.0,
-        'otc_tvol': 1057924358.0,
+        'fb_status': 'N',
+        'fb_tno': 342228,
+        'fb_tval': 163701347122693.0,
+        'fb_tvol': 1057924358.0,
         'tse_index': 1169760.86,
         'tse_index_change': -8155.9,
         'tse_index_change_percent': -0.69,
@@ -535,10 +535,10 @@ def test_parse_index():
         'derivatives_tval': 57759844000.0,
         'derivatives_tvol': 225866.0,
         'market_last_transaction': jdatetime(1399, 12, 24, 14, 39, 40),
-        'otc_status': 'F',
-        'otc_tno': 544617,
-        'otc_tval': 128484547655014.0,
-        'otc_tvol': 1577202926.0,
+        'fb_status': 'F',
+        'fb_tno': 544617,
+        'fb_tval': 128484547655014.0,
+        'fb_tvol': 1577202926.0,
         'tse_index': 1245186.04,
         'tse_index_change': 15808.56,
         'tse_index_change_percent': 1.29,
@@ -677,3 +677,12 @@ def test_get_price_adjustments():
     assert df.columns.to_list() == ['l18', 'l30', 'date', 'adj_pc', 'pc']
     assert len(df) == 6
     assert df.iat[-1, -1] == 1000
+
+
+@patch_get_content('latif_financial_aph.aspx')
+def test_get_adjusted_price_history():
+    adj_df = Instrument(1).get_price_history()
+    assert adj_df.columns.tolist() == ['pmax', 'pmin', 'pf', 'pl', 'tvol', 'pc']
+    assert adj_df.index.name == 'date'
+    assert len(adj_df) == 18
+    assert adj_df.iloc[-1].values.tolist() == [68410, 62366, 63500, 67508, 14222269, 65636]
